@@ -18,16 +18,22 @@ log = logging.getLogger('amqpy')
 
 class Channel(AbstractChannel):
     """
-    The channel class provides methods for a client to establish a virtual connection (a channel) to a server and for
-    both peers to operate the virtual connection thereafter.
+    The channel class provides methods for a client to establish and operate an AMQP channel. All public members are
+    fully thread-safe.
     """
+    ### constants
+    #: Default channel mode
+    CH_MODE_NONE = 0
+    #: Transaction mode
+    CH_MODE_TX = 1
+    #: Publisher confirm mode (RabbitMQ extension)
+    CH_MODE_CONFIRM = 2
 
     def __init__(self, connection, channel_id=None, auto_decode=True):
         """Create a channel bound to a connection and using the specified numeric channel_id, and open on the server
 
-        The 'auto_decode' parameter (defaults to True), indicates whether the library should attempt to decode the body
-        of Messages to a Unicode string if there's a 'content_encoding' property for the message.  If there's no
-        'content_encoding' property, or the decode raises an Exception, the message body is left as plain bytes.
+        If `auto_decode` is enabled (default), incoming Message bodies will be automatically decoded to `str` if
+        possible.
 
         :param connection: the channel's associated Connection
         :param channel_id: the channel's assigned channel ID
@@ -45,10 +51,29 @@ class Channel(AbstractChannel):
 
         super().__init__(connection, channel_id)
 
-        self.is_open = False
-        self.active = True  # flow control
+        # auto decode received messages
+        self.auto_decode = auto_decode
 
-        # returned messages that the server was unable to deliver
+        ### channel state variables:
+
+        #: Current channel open/closed state
+        #:
+        #: :type: bool
+        self.is_open = False
+
+        #: Current channel active state (flow control)
+        #:
+        #: :type: bool
+        self.active = True
+
+        #: Channel mode state (default, transactional, publisher confirm)
+        #:
+        #: :type: int
+        self.mode = 0
+
+        #: Returned messages that the server was unable to deliver
+        #:
+        #: :type: queue.Queue
         self.returned_messages = Queue()
 
         # consumer callbacks dict[consumer_tag str: callable]
@@ -57,15 +82,11 @@ class Channel(AbstractChannel):
         # consumer cancel callbacks dict dict[consumer_tag str: callable]
         self.cancel_callbacks = {}
 
-        self.auto_decode = auto_decode  # auto decode received messages
-
         # set of consumers that have opted for `no_ack` delivery (server will not expect an ack for delivered messages)
         self.no_ack_consumers = set()
 
-        # set first time basic_publish_confirm is called and publisher confirms are enabled for this channel.
-        self.publisher_ack_enabled = self.connection.publisher_ack_enabled
-
-        self._send_open()
+        # open the channel
+        self._open()
 
     def _close(self):
         """Tear down this object, after we've agreed to close with the server
@@ -82,8 +103,17 @@ class Channel(AbstractChannel):
         self.cancel_callbacks.clear()
         self.no_ack_consumers.clear()
 
+    def _open(self):
+        """Open the channel
+        """
+        if self.is_open:
+            return
+
+        self._send_open()
+
     def _revive(self):
         self.is_open = False
+        self.mode = self.CH_MODE_NONE
         self._send_open()
 
     @synchronized('lock')
@@ -206,9 +236,6 @@ class Channel(AbstractChannel):
 
         This method opens a channel.
         """
-        if self.is_open:
-            return
-
         args = AMQPWriter()
         args.write_shortstr('')  # reserved
         self._send_method(Method(spec.Channel.Open, args))
@@ -492,8 +519,8 @@ class Channel(AbstractChannel):
         :raise NotFound: if `passive` is enabled and the queue does not exist
         :raise AccessRefused: if an attempt is made to declare a queue with a reserved name
         :raise ResourceLocked: if an attempt is made to access an exclusive queue declared by another open connection
-        :return: tuple(queue, message_count, consumer_count)
-        :rtype: tuple(str, int, int)
+        :return: queue_declare_ok_t(queue, message_count, consumer_count), or None if `nowait`
+        :rtype: queue_declare_ok_t or None
         """
         arguments = {} if arguments is None else arguments
         args = AMQPWriter()
@@ -511,29 +538,12 @@ class Channel(AbstractChannel):
             return self.wait(allowed_methods=[spec.Queue.DeclareOk])
 
     def _cb_queue_declare_ok(self, method):
-        """Confirms a queue definition
+        """Confirm a queue declare
 
-        This method confirms a Declare method and confirms the name of the queue, essential for automatically-named
-        queues.
+        This method is called when the server responds to a `queue.declare`.
 
-        PARAMETERS:
-
-            queue: shortstr
-
-                Reports the name of the queue. If the server generated a queue name, this field contains that name.
-
-            message_count: long
-
-                number of messages in queue
-
-                Reports the number of messages in the queue, which will be zero for newly-created queues.
-
-            consumer_count: long
-
-                number of consumers
-
-                Reports the number of active consumers for the queue. Note that consumers can suspend activity
-                (Channel.Flow) in which case they do not appear in this count.
+        :return: queue_declare_ok_t(queue, message_count, consumer_count), or None if `nowait`
+        :rtype: queue_declare_ok_t or None
         """
         args = method.args
         return queue_declare_ok_t(args.read_shortstr(), args.read_long(), args.read_long())
@@ -970,6 +980,8 @@ class Channel(AbstractChannel):
         This method publishes a message to a specific exchange. The message will be routed to queues as defined by the
         exchange configuration and distributed to any active consumers when the transaction, if any, is committed.
 
+        If publisher confirms are enabled, this method will automatically wait to receive an "ack" from the server.
+
         :param msg: message
         :param str exchange: exchange name, empty string means default exchange
         :param str routing_key: routing key
@@ -977,9 +989,9 @@ class Channel(AbstractChannel):
         :param bool immediate: request immediate delivery
         :type msg: amqpy.Message
         """
-        if self.publisher_ack_enabled:
-            raise Exception('Publisher confirms are enabled, please use `basic_publish_confirm()` instead')
         self._basic_publish(msg, exchange, routing_key, mandatory, immediate)
+        if self.mode == self.CH_MODE_CONFIRM:
+            self.wait([spec.Basic.Ack])
 
     @synchronized('lock')
     def basic_publish_confirm(self, msg, exchange='', routing_key='', mandatory=False, immediate=False):
@@ -988,7 +1000,7 @@ class Channel(AbstractChannel):
         This method publishes a message to a specific exchange. The message will be routed to queues as defined by the
         exchange configuration and distributed to any active consumers when the transaction, if any, is committed.
 
-        **This method requires the RabbitMQ publisher acknowledgements extension.**
+        **This method requires the RabbitMQ publisher acknowledgements extension, and enabled on the channel.**
 
         :param msg: message
         :param exchange: exchange name, empty string means default exchange
@@ -999,8 +1011,9 @@ class Channel(AbstractChannel):
         :type exchange: str
         :type mandatory: bool
         :type immediate: bool
+        :raise Exception: if publisher confirms are not enabled on the channel
         """
-        if not self.publisher_ack_enabled:
+        if self.mode != self.CH_MODE_CONFIRM:
             raise Exception('Publisher confirms are NOT enabled')
         self._basic_publish(msg, exchange, routing_key, mandatory, immediate)
         self.wait([spec.Basic.Ack])
@@ -1183,7 +1196,8 @@ class Channel(AbstractChannel):
         :raises PreconditionFailed: if the channel is in publish acknowledge mode
         """
         self._send_method(Method(spec.Tx.Select))
-        return self.wait(allowed_methods=[spec.Tx.SelectOk])
+        self.wait(allowed_methods=[spec.Tx.SelectOk])
+        self.mode = self.CH_MODE_TX
 
     def _cb_tx_select_ok(self, method):
         """Confirm transaction mode
@@ -1201,7 +1215,7 @@ class Channel(AbstractChannel):
         called again successfully.
 
         :param bool nowait: if set, the server will not respond to the method and the client should not wait for a reply
-        :raises PreconditionFailed: if the channel is in transactional mode.
+        :raises PreconditionFailed: if the channel is in transactional mode
         """
         args = AMQPWriter()
         args.write_bit(nowait)
@@ -1209,7 +1223,7 @@ class Channel(AbstractChannel):
         self._send_method(Method(spec.Confirm.Select, args))
         if not nowait:
             self.wait(allowed_methods=[spec.Confirm.SelectOk])
-        self.publisher_ack_enabled = True
+        self.mode = self.CH_MODE_CONFIRM
 
     def _cb_confirm_select_ok(self, method):
         """With this method, the broker confirms to the client that the channel is now using publisher confirms
