@@ -38,8 +38,7 @@ class Connection(AbstractChannel):
 
     def __init__(self, *, host='localhost', port=5672, ssl=None, connect_timeout=None,
                  userid='guest', password='guest', login_method='AMQPLAIN', virtual_host='/', locale='en_US',
-                 channel_max=65535, frame_max=131072, heartbeat=0, auto_heartbeat=False,
-                 enable_publisher_ack=False, client_properties=None,
+                 channel_max=65535, frame_max=131072, heartbeat=0, auto_heartbeat=False, client_properties=None,
                  on_blocked=None, on_unblocked=None):
         """Create a connection to the specified host
 
@@ -59,7 +58,6 @@ class Connection(AbstractChannel):
         :param int frame_max: maximum frame payload size in bytes
         :param float heartbeat: heartbeat interval in seconds, 0 disables heartbeat
         :param bool auto_heartbeat: enable automatic heartbeats thread
-        :param bool enable_publisher_ack: enable publisher acknowledgements by default for new channels
         :param client_properties: dict of client properties
         :param on_blocked: callback on connection blocked
         :param on_unblocked: callback on connection unblocked
@@ -69,7 +67,9 @@ class Connection(AbstractChannel):
         :type on_blocked: Callable or None
         :type on_unblocked: Callable or None
         """
-        # `channels` map stores references to all active channels
+        #: Map of `{channel_id: Channel}` for all active channels
+        #:
+        #: :type: dict[int, Channel]
         self.channels = {}  # dict of {channel_id int: Channel}
 
         # the connection object itself is treated as channel 0
@@ -85,8 +85,6 @@ class Connection(AbstractChannel):
         # original heartbeat interval proposed by server
         self.server_heartbeat = None
 
-        self.publisher_ack_enabled = enable_publisher_ack
-
         # callbacks
         self.on_blocked = on_blocked
         self.on_unblocked = on_unblocked
@@ -220,6 +218,24 @@ class Connection(AbstractChannel):
 
         return True
 
+    def _wait_any(self, timeout=None):
+        """Wait for any event on the connection (for any channel)
+
+        This method is called by :meth:`Connection.drain_events()`.
+
+        :param float timeout: timeout
+        :return: method
+        :rtype: amqpy.spec.Method
+        """
+        # check the method queue of each channel
+        for ch_id, channel in self.channels.items():
+            if channel.method_queue:
+                return channel.method_queue.pop(0)
+
+        # do a blocking read for any incoming method
+        method = self.method_reader.read_method(timeout)
+        return method
+
     def drain_events(self, timeout=None):
         """Wait for an event on all channels
 
@@ -230,9 +246,10 @@ class Connection(AbstractChannel):
         :type timeout: float or None
         :raise amqpy.exceptions.Timeout: if the operation times out
         """
-        chan_id, method = self._wait_multiple(self.channels, None, timeout=timeout)
-        channel = self.channels[chan_id]
-        return self.handle_method(method, channel=channel)
+        method = self._wait_any(timeout)
+        assert isinstance(method, Method)
+        channel = self.channels[method.channel_id]
+        return self.handle_method(method, channel)
 
     def close(self, reply_code=0, reply_text='', method_type=method_t(0, 0)):
         """Close connection to the server
